Index: trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionModelCreator.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionModelCreator.cs	(revision 15158)
+++ trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionModelCreator.cs	(revision 15160)
@@ -65,5 +65,5 @@
         ModelParameter.ActualValue = model;
         NegativeLogLikelihoodParameter.ActualValue = new DoubleValue(model.NegativeLogLikelihood);
-        NegativeLogPredictiveProbabilityParameter.ActualValue = new DoubleValue(model.NegativeLooPredictiveProbability);
+        NegativeLogPredictiveProbabilityParameter.ActualValue = new DoubleValue(model.LooCvNegativeLogPseudoLikelihood);
         HyperparameterGradientsParameter.ActualValue = new RealVector(model.HyperparameterGradients);
         return base.Apply();
Index: trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionSolutionCreator.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionSolutionCreator.cs	(revision 15158)
+++ trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessRegressionSolutionCreator.cs	(revision 15160)
@@ -41,5 +41,5 @@
     private const string TestRSquaredResultName = "Test R²";
     private const string CreateSolutionParameterName = "CreateSolution";
-    private const string NegLogPredictiveProbability = "NegativeLogPredictiveProbability (LOO-CV)";
+    private const string NegLogPseudoLikelihood = "Negative log pseudo-likelihood (LOO-CV)";
 
     #region Parameter Properties
@@ -109,12 +109,12 @@
                                  "The Pearson's R² of the Gaussian process solution on the test partition.",
                                  new DoubleValue(s.TestRSquared)));
-          results.Add(new Result(NegLogPredictiveProbability, 
-                                 "The leave-one-out-cross-validation negative log predictive probability.", 
-                                 new DoubleValue(m.NegativeLooPredictiveProbability)));
+          results.Add(new Result(NegLogPseudoLikelihood,
+                                 "The negative log pseudo-likelihood (from leave-one-out-cross-validation).", 
+                                 new DoubleValue(m.LooCvNegativeLogPseudoLikelihood)));
         } else {
           results[SolutionParameterName].Value = s;
           results[TrainingRSquaredResultName].Value = new DoubleValue(s.TrainingRSquared);
           results[TestRSquaredResultName].Value = new DoubleValue(s.TestRSquared);
-          results[NegLogPredictiveProbability].Value = new DoubleValue(m.NegativeLooPredictiveProbability);
+          results[NegLogPseudoLikelihood].Value = new DoubleValue(m.LooCvNegativeLogPseudoLikelihood);
         }
       }
Index: trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/Interfaces/IGaussianProcessModel.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/Interfaces/IGaussianProcessModel.cs	(revision 15158)
+++ trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/Interfaces/IGaussianProcessModel.cs	(revision 15160)
@@ -28,5 +28,5 @@
   public interface IGaussianProcessModel : IConfidenceRegressionModel {
     double NegativeLogLikelihood { get; }
-    double NegativeLooPredictiveProbability { get; }
+    double LooCvNegativeLogPseudoLikelihood { get; }
     double SigmaNoise { get; }
     IMeanFunction MeanFunction { get; }

Index: trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessModel.cs
===================================================================
--- trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessModel.cs	(revision 15158)
+++ trunk/sources/HeuristicLab.Algorithms.DataAnalysis/3.4/GaussianProcess/GaussianProcessModel.cs	(revision 15160)
@@ -46,7 +46,7 @@
 
     [Storable]
-    private double negativeLooPredictiveProbability;
-    public double NegativeLooPredictiveProbability {
-      get { return negativeLooPredictiveProbability; }
+    private double loocvNegLogPseudoLikelihood;
+    public double LooCvNegativeLogPseudoLikelihood {
+      get { return loocvNegLogPseudoLikelihood; }
     }
 
@@ -134,5 +134,5 @@
       this.trainingDataset = cloner.Clone(original.trainingDataset);
       this.negativeLogLikelihood = original.negativeLogLikelihood;
-      this.negativeLooPredictiveProbability = original.negativeLooPredictiveProbability;
+      this.loocvNegLogPseudoLikelihood = original.loocvNegLogPseudoLikelihood;
       this.sqrSigmaNoise = original.sqrSigmaNoise;
       if (original.meanParameter != null) {
@@ -225,5 +225,5 @@
       if (info != 1) throw new ArgumentException("Can't invert matrix to calculate gradients.");
 
       // LOOCV log predictive probability (GPML page 116 and 117)
       var sumLoo = 0.0;
       var ki = new double[n];
@@ -238,5 +238,5 @@
       }
       sumLoo += n * Math.Log(2 * Math.PI);
-      negativeLooPredictiveProbability = 0.5 * sumLoo;
+      loocvNegLogPseudoLikelihood = 0.5 * sumLoo;
 
       for (int i = 0; i < n; i++) {
@@ -225,5 +225,5 @@
       if (info != 1) throw new ArgumentException("Can't invert matrix to calculate gradients.");
 
-      // LOOCV log predictive probability (GPML page 116 and 117)
+      // LOOCV log pseudo-likelihood (or log predictive probability) (GPML page 116 and 117)
       var sumLoo = 0.0;
       var ki = new double[n];